IFirestoreCacheService class abstract

Constructors

IFirestoreCacheService()

Properties

hashCode int
The hash code for this object.
no setterinherited
isReady Future
no setter
onDispose Future<void> Function()?
no setter
onInit Future<void> Function()?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id) FutureOr<void>
dispose() Future<void>
getCachedQuery(String id) FutureOr<TCachedQuery?>
initialise() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String id) FutureOr<Map<String, dynamic>?>
toString() String
A string representation of this object.
inherited
write(String id, Map<String, dynamic> object) FutureOr<void>
writeCachedQuery({required TCachedQuery cachedQuery}) FutureOr<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited