TFirestoreCache class

Constructors

TFirestoreCache({required IFirestoreCacheService firestoreCacheService, TimeOfDay cacheInvalidationTime = const TimeOfDay(hour: 4, minute: 0), Duration? cacheInvalidationDuration, int cacheInvalidationWeekday = DateTime.monday, bool forceCacheRefresh = false})
const

Properties

cacheInvalidationDuration Duration?
final
cacheInvalidationTime TimeOfDay
final
cacheInvalidationWeekday int
final
forceCacheRefresh bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get({required String path, required String id, bool forceCacheRefresh = false}) Future<Map<String, dynamic>?>
isValid({required DateTime now, required DateTime cachedAt}) bool
list({required String path, required String query, bool forceCacheRefresh = false}) Future<List<Map<String, dynamic>>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveDoc({required String docId, required String path, required Map<String, dynamic> doc}) Future<TurboResponse>
saveDocs({required String query, required String path, required List<Map<String, dynamic>> docs}) Future<TurboResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited