TAuthErrors class abstract

Provides constants for various authentication-related error codes.

Prevents instantiation by having a private constructor and is abstract to discourage inheritance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accountExistsWithDifferentCredentials → const String
Error code when an account already exists with different credentials.
captchaCheckFailed → const String
Error code when the captcha verification fails.
credentialAlreadyInUse → const String
Error code when the credential is already associated with a different user account.
emailAlreadyInUse → const String
Error code when attempting to create an account with an email that is already in use.
invalidCredential → const String
Error code when the provided credential is malformed or has expired.
invalidEmail → const String
Error code when the email address is not valid.
invalidLoginCredentials → const String
Error code when the login credentials are invalid.
invalidPhoneNumber → const String
Error code when the phone number is not valid.
invalidVerificationCode → const String
Error code when the SMS verification code is not valid.
invalidVerificationId → const String
Error code when the verification ID for phone auth is not valid.
operationNotAllowed → const String
Error code when the requested authentication operation is not allowed.
providerAlreadyLinked → const String
Error code when attempting to link a provider that is already linked to the account.
quotaExceeded → const String
Error code when the project's quota for the specified operation has been exceeded.
userDisabled → const String
Error code when the user account has been disabled by an administrator.
userNotFound → const String
Error code when the specified user account cannot be found.
weakPassword → const String
Error code when the password does not meet the minimum requirements.
wrongPassword → const String
Error code when the password is invalid for the specified email.