invalidCredential constant
String
const invalidCredential
Error code when the provided credential is malformed or has expired.
Implementation
static const invalidCredential = 'invalid-credential';
Error code when the provided credential is malformed or has expired.
static const invalidCredential = 'invalid-credential';