userDisabled constant
String
const userDisabled
Error code when the user account has been disabled by an administrator.
Implementation
static const userDisabled = 'user-disabled';
Error code when the user account has been disabled by an administrator.
static const userDisabled = 'user-disabled';