userNotFound constant
String
const userNotFound
Error code when the specified user account cannot be found.
Implementation
static const userNotFound = 'user-not-found';
Error code when the specified user account cannot be found.
static const userNotFound = 'user-not-found';