TFirestoreApiDefaults class abstract
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- createdAtFieldName → const String
- defaultIdValue → const String
- documentReferenceFieldName → const String
- idFieldName → const String
- initialiseStream → const bool
- isCollectionGroup → const bool
- tryAddLocalDocumentReference → const bool
- tryAddLocalId → const bool
- unknownValueValue → const String
- updatedAtFieldName → const String
- userIdFieldName → const String
- userIdLocation → const UserIdLocation