TFirestoreException class sealed

A sealed class for Firestore exceptions.

This class provides a type-safe way to handle different types of Firestore errors. Each error type includes context-specific details about what went wrong.

Implemented types
Implementers

Constructors

TFirestoreException.fromFirestoreException(Object error, StackTrace stackTrace, {String? path, String? id, String? query, TOperationType? operationType, Map<String, dynamic>? documentData})
Factory method to create the appropriate exception from a Firestore error.
factory

Properties

code String
The error code.
final
documentData Map<String, dynamic>?
The document data that was being accessed when the error occurred.
final
fullPath String?
Constructs full path from collection and document ID.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
The document ID where the error occurred, if applicable.
final
message String
The error message.
final
operationType TOperationType?
The type of operation that was being performed when the error occurred.
final
path String?
The Firestore collection path where the error occurred, if applicable.
final
query String?
The query that caused the error, if applicable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace where the error occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited