TurboFirestoreGenericException class final

Generic Firestore exception for other error types.

Inheritance

Constructors

TurboFirestoreGenericException({required String message, required String code, String? path, String? id, StackTrace? stackTrace, TOperationType? operationType, Map<String, dynamic>? documentData, required Object originalException})
Creates a new generic Firestore exception.
const

Properties

code String
The error code.
finalinherited
documentData Map<String, dynamic>?
The document data that was being accessed when the error occurred.
finalinherited
fullPath String?
Constructs full path from collection and document ID.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
The document ID where the error occurred, if applicable.
finalinherited
message String
The error message.
finalinherited
operationType TOperationType?
The type of operation that was being performed when the error occurred.
finalinherited
originalException Object
The original exception.
final
path String?
The Firestore collection path where the error occurred, if applicable.
finalinherited
query String?
The query that caused the error, if applicable.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace where the error occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited