TApiFactory<DTO extends TWriteableId> class

Constructors

TApiFactory({required TFirestoreCollection<DTO> collection})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({FirebaseFirestore? firebaseFirestore, GetOptions? getOptions, String path(String collectionName)?, TFirestoreLogger? logger, bool? isCollectionGroup, IFirestoreCacheService? firestoreCacheService, bool? forceCacheRefresh}) TFirestoreApi<DTO>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited