TFirestoreCollection<DTO extends TWriteableId> class

Constructors

TFirestoreCollection({required String apiName, required String collectionName, required DTO fromJson(Map<String, dynamic> json), required Map<String, dynamic> toJson(DTO value), String createdAtFieldName = TFirestoreApiDefaults.createdAtFieldName, String documentReferenceFieldName = TFirestoreApiDefaults.documentReferenceFieldName, DTO fromJsonError(Map<String, dynamic> json)?, String idFieldName = TFirestoreApiDefaults.idFieldName, bool isCollectionGroup = TFirestoreApiDefaults.isCollectionGroup, bool tryAddLocalDocumentReference = TFirestoreApiDefaults.tryAddLocalDocumentReference, bool tryAddLocalId = TFirestoreApiDefaults.tryAddLocalId, String updatedAtFieldName = TFirestoreApiDefaults.updatedAtFieldName, String defaultIdValue = TFirestoreApiDefaults.defaultIdValue, String unknownIdValue = TFirestoreApiDefaults.unknownValueValue, String userIdFieldName = TFirestoreApiDefaults.userIdFieldName, bool tryCache = false, bool forceCacheRefresh = false, String unknownValueValue = TFirestoreApiDefaults.unknownValueValue})
const

Properties

apiName String
final
collectionName String
final
createdAtFieldName String
final
defaultIdValue String
final
documentReferenceFieldName String
final
forceCacheRefresh bool
final
fromJson → DTO Function(Map<String, dynamic> json)
final
fromJsonError → DTO Function(Map<String, dynamic> json)?
final
hashCode int
The hash code for this object.
no setterinherited
idFieldName String
final
isCollectionGroup bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJson Map<String, dynamic> Function(DTO value)
final
tryAddLocalDocumentReference bool
final
tryAddLocalId bool
final
tryCache bool
final
unknownIdValue String
final
unknownValueValue String
final
updatedAtFieldName String
final
userIdFieldName String
final

Methods

api({FirebaseFirestore? firebaseFirestore, GetOptions? getOptions, String path(String collectionName)?, TFirestoreLogger? logger, bool? isCollectionGroup, IFirestoreCacheService? firestoreCacheService, bool? forceCacheRefresh}) TFirestoreApi<DTO>
collectionService<MODEL extends TModel<DTO>>({required TCollectionModelBuilderDef<DTO, MODEL> modelBuilder, TModelDocsBuilderDef<DTO, MODEL>? modelDocsBuilder, TCollectionApiBuilderDef<DTO, MODEL>? apiBuilder, TCollectionStreamBuilderDef<DTO, MODEL>? streamBuilder, TCollectionValueBuilderDef<DTO, MODEL>? initialValue, TCollectionValueBuilderDef<DTO, MODEL>? defaultValue, IFirestoreCacheService? firestoreCacheService, bool initialiseStream = true, TSortOption? initialSort, Set<TFilterInput<dynamic, TFilterOption, dynamic>>? initialFilters, List<Future> readyDeps(User user)?}) TCollectionService<DTO, MODEL>
docService<MODEL extends TModel<DTO>>({required TDocValueBuilderDef<DTO, MODEL> defaultValue, required TDocModelBuilderDef<DTO, MODEL> modelBuilder, TDocApiBuilderDef<DTO, MODEL>? apiBuilder, TDocStreamBuilderDef<DTO, MODEL>? streamBuilder, TDocValueBuilderDef<DTO, MODEL>? initialValue, IFirestoreCacheService? firestoreCacheService, ValueChanged<DTO?>? afterLocalNotifyUpdate, ValueChanged<DTO?>? beforeLocalNotifyUpdate, bool initialiseStream = TFirestoreApiDefaults.initialiseStream, TDocValueBuilderDef<DTO, MODEL>? onMissingRemoteValue, List<Future> readyDeps(User user)?}) TDocService<DTO, MODEL>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited