TList<DTO extends TWriteableId, MODEL extends TModel<DTO>> class

Constructors

TList({required Iterable<MODEL> models, required Set<TFilterInput<dynamic, TFilterOption, dynamic>>? filters, required TSortOption? sort})
TList.empty()
factory

Properties

filters Set<TFilterInput<dynamic, TFilterOption, dynamic>>?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort TSortOption?
no setter
values List<MODEL>
no setter

Methods

add(MODEL model) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String id) → void
toString() String
A string representation of this object.
inherited
updateFilters({required Set<TFilterInput<dynamic, TFilterOption, dynamic>> filters, required Iterable<MODEL> models}) → void
updateSort({required TSortOption sort}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited