TVars class

An abstract class that defines the core variables required for Turbo Firestore documents.

id - The unique identifier for the document now - The timestamp when the document was created/updated userId - The ID of the user who owns/created the document

Constructors

TVars({required String id, required DateTime now, required String? userId, required String defaultIdValue, required String unknownIdValue, required String unknownValue})
const

Properties

defaultIdValue String
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
now DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownIdValue String
final
unknownValue String
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override