getTokenResult method
Returns the cached token result with claims.
Returns null if no token has been cached yet.
Implementation
Future<IdTokenResult?> getTokenResult() async {
return _cachedTokenResult;
}
Returns the cached token result with claims.
Returns null if no token has been cached yet.
Future<IdTokenResult?> getTokenResult() async {
return _cachedTokenResult;
}