firestoreCacheService property

  1. @protected
IFirestoreCacheService? firestoreCacheService
final

Optional Firestore cache service for caching document data locally.

Implementation

@protected
/// Optional Firestore cache service for caching document data locally.
final IFirestoreCacheService? firestoreCacheService;