modelDocsBuilder property

  1. @protected
TModelDocsBuilderDef<DTO, MODEL>? modelDocsBuilder
final

Optional builder function to create the local model documents state from a list of DTOs. If not provided, the state will be created using TModelDocs.fromDtos().

Implementation

@protected
/// Optional builder function to create the local model documents state from a list of DTOs. If not provided, the state will be created using `TModelDocs.fromDtos()`.
final TModelDocsBuilderDef<DTO, MODEL>? modelDocsBuilder;