removeList method
Removes a sorted and filtered list of documents from the local state.
Implementation
void removeList(Object id) => docsNotifier.updateCurrent(
(value) => value..removeList(id),
);
Removes a sorted and filtered list of documents from the local state.
void removeList(Object id) => docsNotifier.updateCurrent(
(value) => value..removeList(id),
);