onMissingRemoteValue property

  1. @protected
TDocValueBuilderDef<DTO, MODEL>? onMissingRemoteValue
final

Whether to attempt to create a missing remote document if the local state is default and no remote document exists.

Implementation

@protected
/// Whether to attempt to create a missing remote document if the local state is default and no remote document exists.
final TDocValueBuilderDef<DTO, MODEL>? onMissingRemoteValue;