streamBuilder property
Optional builder function to create the Firestore stream. If not provided, the stream will be created using the API's streamAllWithConverter() method.
Implementation
@protected
/// Optional builder function to create the Firestore stream. If not provided, the stream will be created using the API's `streamAllWithConverter()` method.
final TDocStreamBuilderDef<DTO, MODEL>? streamBuilder;