services/t_document_service library

Classes

AfterSyncTDocumentService<T extends TWriteableId, API extends TFirestoreApi<T>>
A document service that allows notification after synchronizing data.
BeforeAfterSyncTDocumentService<T extends TWriteableId, API extends TFirestoreApi<T>>
A document service that allows notification both before and after synchronizing data.
BeforeSyncTDocumentService<T extends TWriteableId, API extends TFirestoreApi<T>>
A document service that allows notification before synchronizing data.
TDocumentService<T extends TWriteableId, API extends TFirestoreApi<T>>
A service for managing a single Firestore document with synchronized local state.