TCachedQuery class
- Annotations
-
- @JsonSerializable.new(includeIfNull: true, explicitToJson: true)
Constructors
Properties
- createdAt → DateTime
-
final
-
doc
→ Map<
String, dynamic> ? -
final
-
docs
→ List<
Map< ?String, dynamic> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- query → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
fromJsonFactory
→ const TCachedQuery Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TCachedQuery instance)