TModelDocs<DTO extends TWriteableId, MODEL extends TModel<DTO> > class
Constructors
-
TModelDocs({required TIdMapDef<
MODEL> idMap, required TSortFilteredListsMap<DTO, MODEL> sortFilteredListsMap, required TModelBuilderDef<DTO, MODEL> modelBuilder}) -
const
-
TModelDocs.empty({required TModelBuilderDef<
DTO, MODEL> modelBuilder}) -
factory
-
TModelDocs.fromDtos({required List<
DTO> dtos, required TModelBuilderDef<DTO, MODEL> modelBuilder, TSortFilteredListsMap<DTO, MODEL> ? sortFilteredListsMap}) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ids
→ Iterable<
String> -
no setter
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
- length → int
-
no setter
-
modelBuilder
→ TModelBuilderDef<
DTO, MODEL> -
final
-
models
→ Iterable<
MODEL> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addList(
{required Object id, required TSortFilteredList< DTO, MODEL> sortFilteredList, bool doInitialApply = true}) → List<MODEL> -
dto(
String? id) → DTO? -
exists(
String id) → bool -
findWhere(
bool test(MODEL model)) → Iterable< MODEL> -
get(
String? id) → MODEL? -
getList(
Object? id) → List< MODEL> -
listByIds(
Iterable< String> ids) → List<MODEL> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String id) → MODEL? -
removeList(
Object id) → List< MODEL> -
toString(
) → String -
A string representation of this object.
inherited
-
upsertDto(
DTO newValue) → MODEL -
upsertDtos(
Iterable< DTO> newValues) → List<MODEL> -
upsertValue(
MODEL newValue) → MODEL -
upsertValues(
Iterable< MODEL> newValues) → List<MODEL>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited