services/t_collection_service library
Classes
-
AfterSyncTCollectionService<
T extends TWriteableId, API extends TFirestoreApi< T> > - A collection service that allows notification after synchronizing data.
-
BeforeAfSyncTCollectionService<
T extends TWriteableId, API extends TFirestoreApi< T> > - A collection service that allows notification both before and after synchronizing data.
-
BeforeSyncTCollectionService<
T extends TWriteableId, API extends TFirestoreApi< T> > - A collection service that allows notification before synchronizing data.
-
TCollectionService<
T extends TWriteableId, API extends TFirestoreApi< T> > - A service for managing a collection of Firestore documents with synchronized local state.