firestoreCacheService property
Optional Firestore cache service for caching document data locally.
Implementation
@protected
/// Optional Firestore cache service for caching document data locally.
final IFirestoreCacheService? firestoreCacheService;
Optional Firestore cache service for caching document data locally.
@protected
/// Optional Firestore cache service for caching document data locally.
final IFirestoreCacheService? firestoreCacheService;